/**
 * サンプルプログラム3: 『<biz-stream_home>/sample/java/Sample3.java』
 * 1個のドキュメントレイアウト+2個のページレイアウトでPDFを生成するサンプルです。
 *
 * @author Copyright 2001-2018 BrainSellers.com Corp. All Rights Reserved
 * @version 1.0.2
 * @since 1.0.0
 */
import java.io.FileNotFoundException;
import java.io.IOException;

import com.brainsellers.xml.JaxpXML;
import com.brainsellers.xml.common.XMLSuper;
import com.brainsellers.xml.datatypes.HashtableType;
import com.brainsellers.xml.datatypes.RecordType;
import com.brainsellers.xml.datatypes.StringType;
import com.brainsellers.xml.fo.datasource.ResourceException;

public class Sample3 {
	// XMLファイル名
	private String xml_file = "${base-dir}/sample/java/Sample3-doc.xml";
	// PDFファイル名
	private String pdf_file = "${base-dir}/sample/java/Sample3.pdf";

	public static void main(String argv[]) {
		new Sample3();
		System.exit(0);
	}

	/**
	 * コンストラクタ
	 */
	public Sample3() {

		// データの取得
		HashtableType hashtable_data = this.getHashtableData();
		RecordType record_data = this.getRecordData();
		try {
			// (1) 入出力共にファイル名で指定する
			XMLSuper xml = new JaxpXML(xml_file, pdf_file);

			// (2) レイアウト情報(XML)の解析を行う
			xml.parse();

			// (3) DataSourceを設定する
			// 帳票全体に設定する項目
			xml.setDataSource("hashtable-data", hashtable_data);
			// 繰り返しを要する項目
			xml.setDataSource("record-data", record_data);

			// (4) 座標計算を行う
			xml.calcDataSize();

			// (4) PDFを生成する
			xml.toPDF();

			// (5) PDFを出力する
			xml.close();
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		} catch (ResourceException e) {
			e.printStackTrace();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	/**
	 * データの取得
	 *
	 * @return データを格納したHashtableType
	 */
	public HashtableType getHashtableData() {
		HashtableType data = new HashtableType();
		data.put("company", "サンプル・レイアウト株式会社");
		return data;
	}

	/**
	 * データの取得
	 *
	 * @return データを格納したRecordType
	 */
	public RecordType getRecordData() {
		RecordType data = new RecordType();
		for (int idx = 1; idx < 40; idx++) {
			HashtableType hash = new HashtableType();
			hash.put("製品コード", new StringType("製品コード" + idx));
			hash.put("製品名", new StringType("製品名" + idx));
			hash.put("数量", new StringType("" + idx * 10));
			hash.put("単価", new StringType("" + idx * 100));
			hash.put("金額", new StringType("" + idx * 1000));
			data.add(hash);
		}
		return data;
	}
}
